<?php

namespace Koneko\VuexyWarehouse\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class ProductPrice extends Model
{
    use HasFactory;

    protected $table = 'product_prices';
    protected $primaryKey = 'id';
    public $incrementing = false;
    protected $keyType = 'mediumint';

    protected $fillable = [
        'product_id',
        'pricelist_id',
        'unit_price',
        'discount_percentage',
        'final_price',
        'taxes_transferred',
        'taxes_retained',
        'total_amount',
        'valid_from',
        'valid_to',
        'min_quantity',
        'max_quantity',
    ];

    protected $casts = [
        'unit_price' => 'decimal:6',
        'discount_percentage' => 'decimal:2',
        'final_price' => 'decimal:6',
        'taxes_transferred' => 'decimal:6',
        'taxes_retained' => 'decimal:6',
        'total_amount' => 'decimal:6',
        'valid_from' => 'date',
        'valid_to' => 'date',
        'min_quantity' => 'integer',
        'max_quantity' => 'integer',
    ];

    /**
     * Relación con el producto.
     */
    public function product(): BelongsTo
    {
        return $this->belongsTo(Product::class, 'product_id');
    }

    /**
     * Relación con la lista de precios.
     */
    public function priceList(): BelongsTo
    {
        return $this->belongsTo(PriceList::class, 'pricelist_id');
    }
}
