<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('price_lists', function (Blueprint $table) {
            $table->smallIncrements('id');

            $table->string('name')->index();

            $table->unsignedTinyInteger('type')->index();
            $table->char('c_currency', 3)->charset('ascii')->collation('ascii_general_ci')->nullable(); // Moneda

            $table->timestamps();

            $table->unsignedTinyInteger('status');
        });

        Schema::create('product_prices', function (Blueprint $table) {
            $table->mediumIncrements('id');

            $table->unsignedMediumInteger('product_id')->index(); // products.id
            $table->unsignedSmallInteger('pricelist_id')->index(); // price_lists.id

            $table->decimal('unit_price', 13, 6)->unsigned()->nullable(); // Precio unitario
            $table->decimal('discount_percentage', 5, 2)->unsigned()->nullable(); // Descuento %
            $table->decimal('final_price', 13, 6)->unsigned()->nullable(); // Precio después del descuento

            $table->decimal('taxes_transferred', 13, 6)->unsigned()->nullable(); // Impuestos trasladados
            $table->decimal('taxes_retained', 13, 6)->unsigned()->nullable(); // Impuestos retenidos
            $table->decimal('total_amount', 13, 6)->unsigned()->nullable(); // Importe final

            $table->date('valid_from')->nullable(); // Fecha de inicio de validez
            $table->date('valid_to')->nullable(); // Fecha de fin de validez

            $table->unsignedInteger('min_quantity')->nullable(); // Cantidad mínima para este precio
            $table->unsignedInteger('max_quantity')->nullable(); // Cantidad máxima para este precio

            // Auditoría
            $table->timestamps();

            // Índices y restricciones
            $table->unique(['product_id', 'pricelist_id', 'valid_from', 'valid_to', 'min_quantity', 'max_quantity'])->name('product_pricelist_valid_from_to_min_max_quantity');

            // Relaciones
            $table->foreign('product_id')
                ->references('id')
                ->on('products')
                ->onUpdate('restrict')
                ->onDelete('cascade');

            $table->foreign('pricelist_id')
                ->references('id')
                ->on('price_lists')
                ->onUpdate('restrict')
                ->onDelete('cascade');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('price_lists');
        Schema::dropIfExists('product_prices');
    }
};
